import * as service_types from '@powersync/service-types';
import * as t from 'ts-codec';
export declare const POSTGRES_CONNECTION_TYPE: "postgresql";
export interface NormalizedPostgresConnectionConfig {
    id: string;
    tag: string;
    hostname: string;
    port: number;
    database: string;
    username: string;
    password: string;
    sslmode: 'verify-full' | 'verify-ca' | 'disable';
    cacert: string | undefined;
    client_certificate: string | undefined;
    client_private_key: string | undefined;
}
export declare const PostgresConnectionConfig: t.Intersection<t.Codec<{
    type: string;
    id?: string | undefined;
    tag?: string | undefined;
    debug_api?: boolean | undefined;
}, {
    type: string;
    id?: string | undefined;
    tag?: string | undefined;
    debug_api?: boolean | undefined;
}, string, t.CodecProps>, t.ObjectCodec<{
    type: t.LiteralCodec<"postgresql">;
    /** Unique identifier for the connection - optional when a single connection is present. */
    id: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    /** Tag used as reference in sync rules. Defaults to "default". Does not have to be unique. */
    tag: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    uri: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    hostname: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    port: t.OptionalCodec<t.Codec<number, string | number, string, t.CodecProps>>;
    username: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    password: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    database: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    /** Defaults to verify-full */
    sslmode: t.OptionalCodec<t.Codec<"verify-full" | "verify-ca" | "disable", "verify-full" | "verify-ca" | "disable", string, t.CodecProps>>;
    /** Required for verify-ca, optional for verify-full */
    cacert: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    client_certificate: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    client_private_key: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
    /** Expose database credentials */
    demo_database: t.OptionalCodec<t.Codec<boolean, boolean, string, t.CodecProps>>;
    /**
     * Prefix for the slot name. Defaults to "powersync_"
     */
    slot_name_prefix: t.OptionalCodec<t.Codec<string, string, string, t.CodecProps>>;
}>>;
/**
 * Config input specified when starting services
 */
export type PostgresConnectionConfig = t.Decoded<typeof PostgresConnectionConfig>;
/**
 * Resolved version of {@link PostgresConnectionConfig}
 */
export type ResolvedConnectionConfig = PostgresConnectionConfig & NormalizedPostgresConnectionConfig;
/**
 * Validate and normalize connection options.
 *
 * Returns destructured options.
 */
export declare function normalizeConnectionConfig(options: PostgresConnectionConfig): NormalizedPostgresConnectionConfig;
export declare function isPostgresConfig(config: service_types.configFile.DataSourceConfig): config is PostgresConnectionConfig;
/**
 * Check whether the port is in a "safe" range.
 *
 * We do not support connecting to "privileged" ports.
 */
export declare function validatePort(port: string | number): number;
/**
 * Construct a postgres URI, without username, password or ssl options.
 *
 * Only contains hostname, port, database.
 */
export declare function baseUri(options: NormalizedPostgresConnectionConfig): string;
